/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
package com.ebmwebsourcing.easycommons.soap;

import static org.junit.Assert.*;

import java.util.logging.Logger;

import org.junit.Test;

public class SoapComparatorTest {

    public static Logger log = Logger.getLogger(SoapComparatorTest.class.getName());

    private static final void assertCommutativeEquivalence(boolean isEquivalent, String operand1,
            String operand2) {
        assertEquals(isEquivalent, SoapComparator.isEquivalent(operand1, operand2));
        assertEquals(isEquivalent, SoapComparator.isEquivalent(operand2, operand1));
    }

    @Test
    public void testIsEquivalent0() throws Exception {
        String xml1 = "<SOAP-ENV:Envelope xmlns:SOAP-ENV='http://schemas.xmlsoap.org/soap/envelope/'><SOAP-ENV:Header/><SOAP-ENV:Body><echoString/></SOAP-ENV:Body></SOAP-ENV:Envelope>";
        String xml2 = "<S:Envelope xmlns:S='http://schemas.xmlsoap.org/soap/envelope/'><S:Header/><S:Body><echoString/></S:Body></S:Envelope>";
        assertCommutativeEquivalence(true, xml1, xml2);
    }

    @Test
    public void testIsEquivalent1() throws Exception {
        String xml1 = "<SOAP-ENV:Envelope xmlns:SOAP-ENV='http://schemas.xmlsoap.org/soap/envelope/'><SOAP-ENV:Header/><SOAP-ENV:Body><echoString/></SOAP-ENV:Body></SOAP-ENV:Envelope>";
        String xml2 = "<S:Envelope xmlns:toto='http://unusednamespacemapping' "
                + "xmlns:S='http://schemas.xmlsoap.org/soap/envelope/'><S:Header/><S:Body><echoString/></S:Body></S:Envelope>";
        assertCommutativeEquivalence(true, xml1, xml2);
    }

    @Test
    public void testIsEquivalent2() throws Exception {
        String xml1 = "<SOAP-ENV:Envelope xmlns:SOAP-ENV='http://schemas.xmlsoap.org/soap/envelope/'><SOAP-ENV:Header/><SOAP-ENV:Body><echoString/></SOAP-ENV:Body></SOAP-ENV:Envelope>";
        String xml2 = "<S:Envelope xmlns:toto='http://unusednamespacemapping' "
                + "xmlns:S='http://schemas.xmlsoap.org/soap/envelope/'><S:Body><echoString/></S:Body></S:Envelope>";
        assertCommutativeEquivalence(true, xml1, xml2);
    }

    @Test
    public void testIsEquivalent3() throws Exception {
        String xml1 = "<SOAP-ENV:Envelope xmlns:SOAP-ENV='http://schemas.xmlsoap.org/soap/envelope/'><SOAP-ENV:Header/><SOAP-ENV:Body><echoString/></SOAP-ENV:Body></SOAP-ENV:Envelope>";
        String xml2 = "<S:Envelope xmlns:toto='http://unusednamespacemapping' "
                + "xmlns:S='http://schemas.xmlsoap.org/soap/envelope/'><S:Header><m:Trans xmlns:m=\"http://www.w3schools.com/transaction/\"\r\n"
                + "  S:mustUnderstand=\"1\">234\r\n"
                + "  </m:Trans></S:Header><S:Body><echoString/></S:Body></S:Envelope>";
        assertCommutativeEquivalence(false, xml1, xml2);
    }

    @Test
    public void testIsEquivalent4() throws Exception {
        String xml1 = "<S:Envelope "
                + "xmlns:S='http://schemas.xmlsoap.org/soap/envelope/'><S:Header><m:Trans xmlns:m=\"http://www.w3schools.com/transaction/\"\r\n"
                + "  S:mustUnderstand=\"1\">234\r\n"
                + "  </m:Trans></S:Header><S:Body><echoString2/></S:Body></S:Envelope>";

        String xml2 = "<S:Envelope xmlns:toto='http://unusednamespacemapping' "
                + "xmlns:S='http://schemas.xmlsoap.org/soap/envelope/'><S:Header><m:Trans xmlns:m=\"http://www.w3schools.com/transaction/\"\r\n"
                + "  S:mustUnderstand=\"1\">234\r\n"
                + "  </m:Trans></S:Header><S:Body><echoString/></S:Body></S:Envelope>";
        assertCommutativeEquivalence(false, xml1, xml2);
    }
}
