/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
package com.ebmwebsourcing.easycommons.xml;

import java.io.File;
import java.net.URI;
import java.net.URISyntaxException;

import javax.xml.transform.Source;
import javax.xml.transform.TransformerException;

import junit.framework.Assert;

import org.junit.Test;

import com.ebmwebsourcing.easycommons.xml.resolver.URIMultipleResolvers;

public class URIMultipleResolversTest {

    @Test
    public void testAllNull() throws TransformerException {
    	Source s = new URIMultipleResolvers().resolve(null, null);
        Assert.assertNull(s);
    }

    @Test
    public void testBaseUriNull() throws TransformerException {
        Assert.assertNotNull(new URIMultipleResolvers().resolve(null, "test.xml"));
    }

    @Test
    public void testFile() throws TransformerException {
        File f = new File("./src/test/resources");
        Assert.assertNotNull(new URIMultipleResolvers().resolve("test.xml", f.toURI().toString()));
    }

    @Test
    public void testJar() throws TransformerException, URISyntaxException {
        URI jar = new URI("jar:" + new File("./src/test/resources/ws-echo.jar").toURI() + "!/wsdl/echo.wsdl");
        Assert.assertEquals("jar", jar.getScheme());
        Assert.assertNotNull(new URIMultipleResolvers().resolve(jar.toString(), null));
    }


    @Test
    public void testSpace() throws URISyntaxException, TransformerException {
        File f = new File("./src/test/resources/petals link/");
        Assert.assertNotNull(new URIMultipleResolvers().resolve("test.xml", f.toURI().toString()));
    }
    

}
